summaryrefslogtreecommitdiff
path: root/poezio/core/handlers.py
diff options
context:
space:
mode:
Diffstat (limited to 'poezio/core/handlers.py')
-rw-r--r--poezio/core/handlers.py18
1 files changed, 7 insertions, 11 deletions
diff --git a/poezio/core/handlers.py b/poezio/core/handlers.py
index 6fa9935b..030a43e5 100644
--- a/poezio/core/handlers.py
+++ b/poezio/core/handlers.py
@@ -472,7 +472,7 @@ class HandlerCore:
def on_nick_received(self, message):
"""
- Called when a pep notification for an user nickname
+ Called when a pep notification for a user nickname
is received
"""
contact = roster[message['from'].bare]
@@ -527,7 +527,7 @@ class HandlerCore:
def on_mood_event(self, message):
"""
- Called when a pep notification for an user mood
+ Called when a pep notification for a user mood
is received.
"""
contact = roster[message['from'].bare]
@@ -561,11 +561,11 @@ class HandlerCore:
'Mood')
else:
self.core.information(
contact.bare_jid + ' stopped having his/her mood.', 'Mood')
def on_activity_event(self, message):
"""
- Called when a pep notification for an user activity
+ Called when a pep notification for a user activity
is received.
"""
contact = roster[message['from'].bare]
@@ -606,12 +606,12 @@ class HandlerCore:
contact.activity, 'Activity')
else:
self.core.information(
contact.bare_jid + ' stopped doing his/her activity.',
'Activity')
def on_tune_event(self, message):
"""
- Called when a pep notification for an user tune
+ Called when a pep notification for a user tune
is received
"""
contact = roster[message['from'].bare]
@@ -653,8 +653,6 @@ class HandlerCore:
"""
Triggered whenever a message is received from a multi-user chat room.
"""
- if message['subject']:
- return
room_from = message['from'].bare
if message['type'] == 'error': # Check if it's an error
@@ -1015,7 +1013,7 @@ class HandlerCore:
contact.pending_out = False
else:
self.core.information(
- '%s does not want you to receive his/her/its status anymore.' %
+ '%s does not want you to receive their/its status anymore.' %
jid, 'Roster')
self.core.tabs.first().state = 'highlight'
if isinstance(self.core.tabs.current_tab, tabs.RosterInfoTab):
@@ -1312,8 +1310,6 @@ class HandlerCore:
"""
Triggered when the topic is changed.
"""
- if message['body'] or message['thread']:
- return
nick_from = message['mucnick']
room_from = message.get_mucroom()
tab = self.core.tabs.by_name_and_class(room_from, tabs.MucTab)
@@ -561,11 +561,11 @@ class HandlerCore:
else:
self.core.information(
- contact.bare_jid + ' stopped having his/her mood.', 'Mood')
+ contact.bare_jid + ' stopped having their mood.', 'Mood')
def on_activity_event(self, message):
"""
@@ -606,12 +606,12 @@ class HandlerCore:
else:
self.core.information(
- contact.bare_jid + ' stopped doing his/her activity.',
+ contact.bare_jid + ' stopped doing their activity.',
'Activity')
def on_tune_event(self, message):